==> haskell-butcher-1.3.3.2-497-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-butcher.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 butcher
version:              1.3.3.2
visibility:           public
id:                   butcher-1.3.3.2-GiFVyyJSqpC1uTF7yifsz4
key:                  butcher-1.3.3.2-GiFVyyJSqpC1uTF7yifsz4
license:              BSD-3-Clause
copyright:            Copyright (C) 2016-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
stability:            experimental
homepage:             https://github.com/lspitzner/butcher/
synopsis:
    Chops a command or program invocation into digestable pieces.

description:
    See the <https://github.com/lspitzner/butcher/blob/master/README.md README> (it is properly formatted on github).

category:             UI
abi:                  74ced9e971949cc90e232a5c299bf64e
exposed:              True
exposed-modules:
    UI.Butcher.Monadic UI.Butcher.Monadic.BuiltinCommands
    UI.Butcher.Monadic.Command UI.Butcher.Monadic.Flag
    UI.Butcher.Monadic.IO UI.Butcher.Monadic.Interactive
    UI.Butcher.Monadic.Param UI.Butcher.Monadic.Pretty
    UI.Butcher.Monadic.Types

hidden-modules:
    UI.Butcher.Monadic.Internal.Types UI.Butcher.Monadic.Internal.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-butcher
hs-libraries:         HSbutcher-1.3.3.2-GiFVyyJSqpC1uTF7yifsz4
depends:
    base-4.17.2.1 bifunctors-5.6.2-8xUOLzX1S3EDLz7f7fpjrz
    containers-0.6.7 deque-0.4.4.2-3pecX8iSs2x1ZxAsn9mmy7
    extra-1.7.16-EUCiKuF8A8QJZrcHdWAV4o free-5.2-71fbrzB20syG3JIIOZHARR
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    multistate-0.8.0.4-7k6vJLqGKcZEIl7i3K740q pretty-1.1.3.6
    transformers-0.5.6.2 unsafe-0.0-GQ6Zydb4lCS7B1Ck4GrK4S
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-butcher/html/butcher.haddock
haddock-html:         /usr/share/doc/haskell-butcher/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-butcher-1.3.3.2-498-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-butcher.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 butcher
version:              1.3.3.2
visibility:           public
id:                   butcher-1.3.3.2-LvR7dRsCure7n1itkiWZ4B
key:                  butcher-1.3.3.2-LvR7dRsCure7n1itkiWZ4B
license:              BSD-3-Clause
copyright:            Copyright (C) 2016-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
stability:            experimental
homepage:             https://github.com/lspitzner/butcher/
synopsis:
    Chops a command or program invocation into digestable pieces.

description:
    See the <https://github.com/lspitzner/butcher/blob/master/README.md README> (it is properly formatted on github).

category:             UI
abi:                  a1d5a9056e97031261171c817874cab8
exposed:              True
exposed-modules:
    UI.Butcher.Monadic UI.Butcher.Monadic.BuiltinCommands
    UI.Butcher.Monadic.Command UI.Butcher.Monadic.Flag
    UI.Butcher.Monadic.IO UI.Butcher.Monadic.Interactive
    UI.Butcher.Monadic.Param UI.Butcher.Monadic.Pretty
    UI.Butcher.Monadic.Types

hidden-modules:
    UI.Butcher.Monadic.Internal.Types UI.Butcher.Monadic.Internal.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-butcher
hs-libraries:         HSbutcher-1.3.3.2-LvR7dRsCure7n1itkiWZ4B
depends:
    base-4.17.2.1 bifunctors-5.6.2-CnW8QhOdnhQ7eFthNEafYi
    containers-0.6.7 deque-0.4.4.2-Iz1ELsRfcyFAbdtRtttgN4
    extra-1.7.16-LFhHReVYXhkAHHlVLFa5k7 free-5.2-2lR9MHj3l9qIsFnS11rTO0
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    multistate-0.8.0.4-FMo8UOPoSc0Crv8BRPQl3c pretty-1.1.3.6
    transformers-0.5.6.2 unsafe-0.0-GQ6Zydb4lCS7B1Ck4GrK4S
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-butcher/html/butcher.haddock
haddock-html:         /usr/share/doc/haskell-butcher/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
